@@ -378,7 +378,7 @@ static inline void fill_time(struct timeval *tv) {
 }
 
 static inline unsigned int min_uint(unsigned int a, unsigned int b) {
-    return a < b ? a : b;
+    return (a < b) ? a : b;
 }
 
 static inline uint32_t mkdev_26(unsigned long maj, unsigned long min) {
