@@ -16,14 +16,18 @@ include/pctrl.h
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
 #ifndef TTYREPLAY_PCTRL_H
 #define TTYREPLAY_PCTRL_H 1
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 enum {
     PCTRL_NONE = 0,
     PCTRL_PREV,
@@ -45,6 +49,10 @@ extern void pctrl_exit(void);
 extern void pctrl_activate(struct pctrl_info *);
 extern void pctrl_deactivate(int);
 
+#ifdef __cplusplus
+} // extern "C"
+#endif
+
 #endif // TTYREPLAY_PCTRL_H
 
 //=============================================================================
