@@ -16,8 +16,8 @@ include/rpl_packet.h - Packet definitions for RPLD and RPLDEV
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -44,9 +44,9 @@ enum {
     EVT_WRITE,
     EVT_IOCTL,
     EVT_CLOSE,
-    EVT_INIT    = 'i',
-    EVT_DEINIT  = 'd',
-    EVT_ID_PROG = 240,
+    EVT_INIT    = 0x69,
+    EVT_DEINIT  = 0x64,
+    EVT_ID_PROG = 0xF0,
     EVT_ID_DEVPATH,
     EVT_max,
     MAGIC_SIG = 0xEE,
