@@ -16,8 +16,8 @@ user/infod.c - INFO socket for RPLD
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -47,7 +47,7 @@ static void getinfo_text(uint32_t, int);
 static void getinfo(uint32_t, int);
 static void zero_counters(uint32_t);
 
-inline static const char *basename_pp(const char *, const char *);
+static inline const char *basename_pp(const char *, const char *);
 static void block_signals(void);
 static void print_entry_text(int, struct tty *);
 static void print_entry(int, struct tty *);
@@ -254,7 +254,7 @@ static void zero_counters(uint32_t dev) {
 }
 
 //-----------------------------------------------------------------------------
-inline static const char *basename_pp(const char *s, const char *t) {
+static inline const char *basename_pp(const char *s, const char *t) {
     const char *p;
     if(s == NULL) { return NULL; }
 
@@ -262,11 +262,10 @@ inline static const char *basename_pp(const char *s, const char *t) {
         if((p = HX_strbchr(t, p, '/')) != NULL) {
             return s + (p - t) + 1;
         }
-    } else if((p = strrchr(s, '/')) != NULL) {
-        return p + 1;
+        return s;
     }
 
-    return s;
+    return HX_basename(s);
 }
 
 static void block_signals(void) {
