@@ -16,8 +16,8 @@ user/pctrl.c - "Remote control" for ttyreplay
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -57,8 +57,8 @@ int pctrl_init(void) {
     tcgetattr(ctty, &tio_default);
 
     sa.sa_handler = pctrl_deactivate;
-    sigemptyset(&sa.sa_mask);
     sa.sa_flags   = SA_RESTART | SA_ONESHOT;
+    sigemptyset(&sa.sa_mask);
     sigaction(SIGINT,  &sa, NULL);
     sigaction(SIGQUIT, &sa, NULL);
     sigaction(SIGTERM, &sa, NULL);
