@@ -16,8 +16,8 @@ user/rplctl.c - INFOD client
 
   You should have received a copy of the GNU General Public License
   along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-  Boston, MA 02111-1307, USA.
+  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
   -- For details, see the file named "LICENSE.GPL2"
 =============================================================================*/
@@ -27,7 +27,6 @@ user/rplctl.c - INFOD client
 #include <sys/stat.h>
 #include <sys/un.h>
 #include <errno.h>
-#include <popt.h>
 #include <sched.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -46,6 +45,7 @@ static void send_int(int, unsigned char, uint32_t);
 static int unix_client(const char *);
 
 static int get_options(int *, const char ***);
+static void getopt_proc(const struct HXoptcb *);
 
 // Global variables
 static struct {
@@ -54,7 +54,7 @@ static struct {
     .do_listing = 0, // -L
     .parseable  = 0, // -t
 };
-static int Sockfd = -1;
+static int Sockfd = -1, Got_arg = 0;
 
 //-----------------------------------------------------------------------------
 int rplctl_main(int argc, const char **argv) {
@@ -64,7 +64,11 @@ int rplctl_main(int argc, const char **argv) {
         return EXIT_FAILURE;
     }
 
-    if(get_options(&argc, &argv) == 0) {
+    if(get_options(&argc, &argv) <= 0) {
+        return EXIT_FAILURE;
+    }
+
+    if(Got_arg == 0) {
         if(!Opt.parseable) {
             printf("A %-7s %13s %9s %s\n", _("TTY"), _("BYTES IN"),
              _("OUT"), _("FILENAME"));
@@ -182,90 +186,64 @@ static int unix_client(const char *port) {
 
 //-----------------------------------------------------------------------------
 static int get_options(int *argc, const char ***argv) {
-    static const char *_empty_argv[] = {NULL};
-    char *tmp;
-    struct poptOption options_table[] = {
-        {NULL, 'A', POPT_ARG_STRING, &tmp, 'A',
-         _("Capture data from tty"), "tty"},
-        {NULL, 'D', POPT_ARG_STRING, &tmp, 'D',
-         _("Ignore data from tty"), "tty"},
-        {NULL, 'L', POPT_ARG_STRING | POPT_ARGFLAG_OPTIONAL, &tmp, 'L',
-         _("Explicitly request info about all [or given] ttys"), "tty"},
-        {NULL, 'S', POPT_ARG_STRING, &tmp, 'S',
-         _("Ignore data from tty until next tty session"), "tty"},
-        {NULL, 'X', POPT_ARG_STRING, &tmp, 'X',
-         _("Close the tty's logfile"), "tty"},
-        {NULL, 'Z', POPT_ARG_STRING | POPT_ARGFLAG_OPTIONAL, &tmp, 'Z',
-         _("Zero all packet and byte counters"), "tty"},
-        {NULL, 'f', POPT_ARG_STRING, &GOpt.infod_port, 0,
-         _("Path to the INFOD socket"), "file"},
-        {NULL, 't', POPT_ARG_NONE, &Opt.parseable, 0,
-         _("Generate easy-parseable output"), NULL},
-        POPT_AUTOHELP
-        POPT_TABLEEND
+    struct HXoption options_table[] = {
+        {.sh = 'A', HXOPT_STRING, .cb = getopt_proc,
+         .help = _("Capture data from tty"), _("tty")},
+        {.sh = 'D', HXOPT_STRING, .cb = getopt_proc,
+         .help = _("Ignore data from tty"), _("tty")},
+        {.sh = 'L', HXOPT_STRING | HXOPT_OPTIONAL, .cb = getopt_proc,
+         .help = _("Explicitly request info about all [or given] ttys"),
+         .htyp = _("tty")},
+        {.sh = 'S', HXOPT_STRING, .cb = getopt_proc,
+         .help = _("Ignore data from tty until next tty session"), _("tty")},
+        {.sh = 'X', HXOPT_STRING, .cb = getopt_proc,
+         .help = _("Close the tty's logfile"), _("tty")},
+        {.sh = 'Z', HXOPT_STRING | HXOPT_OPTIONAL, .cb = getopt_proc,
+         .help = _("Zero all packet and byte counters"), .htyp = _("tty")},
+        {.sh = 'f', HXOPT_STRING, .ptr = &GOpt.infod_port,
+         .help = _("Path to the INFOD socket"), .htyp = _("file")},
+        {.sh = 't', HXOPT_NONE, .ptr = &Opt.parseable,
+         .help = _("Generate grepable output")},
+        HXOPT_AUTOHELP,
+        HXOPT_TABLEEND,
     };
 
-    poptContext ctx;
-    const char **args;
-    int c, argk, got = 0;
-
-    ctx = poptGetContext(**argv, *argc, *argv, options_table, 0);
-    while((c = poptGetNextOpt(ctx)) >= 0) {
-        static const int mapping[] = {
-            ['A'] = IFP_ACTIVATE,
-            ['D'] = IFP_DEACTIVATE,
-            ['S'] = IFP_DEACTIVSES,
-            ['X'] = IFP_REMOVE,
-            ['Z'] = IFP_ZERO,
-        };
-        switch(c) {
-            case 'A':
-            case 'D':
-            case 'S':
-            case 'X': {
-                uint32_t dev;
-                ++got;
-                if((dev = getdev(tmp)) != 0) {
-                    send_int(Sockfd, mapping[c], dev);
-                }
-                free(tmp);
-                break;
-            }
-            case 'L': {
-                uint32_t dev = 0;
-                ++got;
-                if(tmp != NULL) { dev = getdev(tmp); }
-                send_int(Sockfd, IFP_GETINFO_A, dev);
-                free(tmp);
-                break;
-            }
-            case 'Z': {
-                uint32_t dev = 0;
-                ++got;
-                if(tmp != NULL) { dev = getdev(tmp); }
-                send_int(Sockfd, mapping[c], dev);
-                free(tmp);
-                break;
-            }
-        }
-    }
-
-    if(c < -1) {
-        fprintf(stderr, "%s: %s\n", poptBadOption(ctx, 0), poptStrerror(c));
-        poptFreeContext(ctx);
-        return -1;
-    }
-
-    if((args = poptGetArgs(ctx)) != NULL) {
-        argk = count_args(args);
-        poptDupArgv(argk, args, argc, argv);
-    } else {
-        *argc = 0;
-        *argv = _empty_argv;
-    }
-
-    poptFreeContext(ctx);
-    return got;
+    return HX_getopt(options_table, argc, argv, HXOPT_USAGEONERR);
 }
 
+static void getopt_proc(const struct HXoptcb *cbi) {
+    static const int mapping[] = {
+        ['A'] = IFP_ACTIVATE,
+        ['D'] = IFP_DEACTIVATE,
+        ['S'] = IFP_DEACTIVSES,
+        ['X'] = IFP_REMOVE,
+        ['Z'] = IFP_ZERO,
+    };
+    switch(cbi->tsh) {
+        case 'A':
+        case 'D':
+        case 'S':
+        case 'X': {
+            uint32_t dev;
+            ++Got_arg;
+            if((dev = getdev(cbi->s)) != 0) {
+                send_int(Sockfd, mapping[(int)cbi->tsh], dev);
+            }
+            break;
+        }
+        case 'L': {
+            uint32_t dev = (cbi->s != NULL) ? getdev(cbi->s) : 0;
+            ++Got_arg;
+            send_int(Sockfd, IFP_GETINFO_A, dev);
+            break;
+        }
+        case 'Z': {
+            uint32_t dev = (cbi->s != NULL) ? getdev(cbi->s) : 0;
+            ++Got_arg;
+            send_int(Sockfd, mapping[(int)cbi->tsh], dev);
+            break;
+        }
+    }
+    return;
+}
 //=============================================================================
