@@ -182,10 +182,13 @@ static void mainloop(int fd) {
         if((eax = read(fd, &packet, sizeof(struct rpldev_packet))) <
          (ssize_t)sizeof(struct rpldev_packet)) {
             struct stat sb;
+#ifdef __OpenBSD__
+            int e = errno;
+#endif
             fstat(fd, &sb);
             if(!S_ISREG(sb.st_mode)) {
 #ifdef __OpenBSD__
-                if(errno == EINTR) { continue; }
+                if(e == EINTR) { continue; }
 #endif
                 fprintf(stderr, _("\n" "Short read: %ld bytes only. Error %d:"
                  " %s\n"), (long)eax, errno, strerror(errno));
@@ -492,7 +495,7 @@ static void fill_info(struct tty *tty, const char *aux_sdev) {
       strftime(fmtime, sizeof(fmtime), "%H%M%S", &now_tm);
     }
 
-    HX_strrep(buf, sizeof(buf), GOpt.ofmt, catalog);
+    HX_strrep5(GOpt.ofmt, catalog, buf, sizeof(buf));
     HX_strclone(&tty->log, buf);
     return;
 }
